All Classes and Interfaces

Class
Description
Implementation of CodeCopyMapper for default mapping (copy only children).
The default implementation of CodeLanguage (for Java).
CodeMutableItemWithType that represents an Annotation instance.
CodeExpression for an array instatiation.
Syntax example:
CodeGenericType representing an array of a component type.
CodeAtomicStatement representing an assignment of a variable to the result of an expression.
An atomic CodeStatement (unlike a CodeBlock).
CodeStatement for a block that groups multiple statements.
CodeComment representing a multi-line comment.
CodeBlock for a do while statement.
CodeBlock for an for block.
CodeBlock for an if block.
CodeBlock for initializer code of a CodeType.
CodeBlock that is a regular CodeStatement.
CodeBlock for a while do statement.
Syntax:
CodeExpression to cast an expression to a specific type.
CodeStatement for a comment.
CodeComment representing a sequence of CodeComments.
CodeOperator for comparison expressions.
CodeExpression representing a condition.
CodeExpression for a constant value.
CodeOperation representing a constructor of a CodeType.
CodeOperationInvocation representing the invocation of a CodeConstructor.
Syntax example:
CodeMembers as a container for the CodeConstructors.
CodeNode as common anchestor of CodePackage and CodeSource.
A CodeContext is the main entry point of this API.
Call-back interface to map and resolve CodeNodes whilst copying.
Implementation of CodeCopyMapper for default mapping (copy only children).
Enum with the available types defining the relation of a CodeNodeItem to map to the CodeNodeItem to copy.
CodeItem representing API documentation (e.g.
Definition of format(s) to be able to convert CodeDoc to.
Represents a parsed link of a CodeDoc.
Represents a method reference for a CodeDocLink.
CodeElement that has a name.
CodeElement that optionally has type variables.
CodeOperationArg for an exception in a throws declaration of a CodeOperation.
CodeItem for an expression.
CodeCondition wrapping an expression that evaluates to a boolean result (like a Predicate).
This is a low-level factory for code objects.
CodeMember for a field of a CodeType.
CodeExpression referencing a CodeField from an optinal expression.
CodeMembers as a container for the CodeFields.
Abstract top-level interface for any item of code as defined by this API.
CodeForExpression for a foreach loop.
CodeForExpression for a regular for loop.
CodeNodeItem representing a function such as a CodeMethod or a CodeLambdaExpression.
CodeItem that represents a (potentially generic) type (similar to Type).
CodeItem representing an import.
TODO hohwille This type ...
An item of a CodeImport as used in type-scrypt (ES6).
CodeComment representing an inline comment.
Abstract top-level interface for any item of code as defined by this API.
CodeItem that has an optional comment.
CodeItem representing a declaration.
CodeItem that has a name.
CodeExpression representing a lambda function.
Syntax:
Interface to abstract from a concrete language.
CodeConstant representing a literal value.
Abstract interface to get (or load) types.
CodeVariable that is locally defined in a CodeBlock.
Syntax:
CodeAtomicStatement to declare multiple CodeLocalVariables in a single statement.
CodeElementWithModifiers representing a Member of a CodeType that is either a CodeOperation or a CodeField.
CodeExpression referencing a CodeMember from an optional expression.
CodeItem that groups all CodeMembers of a type.
CodeItem with merge support.
Enum with the available strategies for a merge.
Call-back Interface to decide which merge strategy to apply for a merge.
Implementation of CodeMergeStrategyDecider that will always decide to merge but overrides the body if a @Generated annotation is present and otherwise keeps the original body.
CodeOperation that represents a method of a CodeType.
CodeOperationInvocation representing the invocation of a CodeConstructor.
Syntax:
CodeMembers as a container for the CodeMethods.
Represents the visibility of a CodeMethod.
A code object that can be mutable or immutable.
CodeItem that can be mutable.
CodeItem that has an optional comment.
CodeItem that has a simple name and a qualified name, that is qualified via the parent package.
Represents a parsed hierarchical name like a qualified name or a part of it (e.g.
CodeNAryOperator that can arbitrary types of result (numeric or non-numeric such as String).
CodeNAryOperator that takes boolean arguments and has a boolean result.
CodeNAryOperator that is both numeric and boolean.
CodeNAryOperator that takes numeric arguments and in such case has a numeric result.
CodeOperator that is N-ary.
A node of the abstract syntax tree (AST) that is connected with its parent.
CodeItem containing CodeItems of a particular type.
CodeNode that is also a CodeItem.
CodeItem containing CodeItems of a particular type.
CodeItem containing CodeItems of a particular type.
CodeNodeItemContainerHierarchical containing named CodeItems of a particular type.
CodeItem containing CodeItems of a particular type.
CodeNodeItemContainerHierarchical containing named CodeItems of a particular type.
CodeItem that has a generic parent.
CodeMember representing an invokable operation such as a CodeMethod or CodeConstructor.
A CodeMutableItemWithType representing a argument of a CodeOperation such as CodeParameter, CodeException or CodeReturn.
CodeExpression representing the invocation of a CodeOperation.
CodeMembers as a container for the CodeOperations.
CodeItem for an operator symbol.
CodeExpression that applies an operator to a number of arguments.
CodeElement representing a Package (or similar namespace concept in case of other language).
CodeOperationArg for a parameter (argument) of a CodeOperation.
CodeGenericType representing a parameterized type.
Abstract interface for any top-level CodeElement such as CodePackage or CodeFile.
CodeMembers as a container for the CodePropertys.
Abstract interface for a field of a CodeType.
Abstract interface used to retrieve CodePackages and CodeTypes.
CodeAssignment that is a regular assignment statement (unlike a CodeLocalVariable).
Syntax:
CodeOperationArg for the returned result of a CodeMethod.
CodeAtomicStatement returning the result of an expression.
CodeComment for a single comment such as CodeSingleLineComment or CodeInlineComment.
CodeSingleComment representing a single-line comment.
A CodeSource represents a physical location where CodePackages and CodeFiles are retrieved from.
Descriptor with details of a CodeSource.
CodeItem with a single statement or a complete block of statements.
CodeNodeItemContainerHierarchical containing the super types of a CodeType.
CodeExpression for a ternary expression.
CodeElement representing a type (similar to Class).
Represents the type of a CodeType.
CodeGenericType representing a placeholder for a generic type.
CodeGenericType representing a type variable.
CodeGenericType representing a type variable.
CodeOperator that is unary and takes exactly one single argument.
CodeExpression for a variable (local variable, parameter, field).
CodeVariable for the surrounding instance.
Represents the visibility of a CodeMethod.
Generic visitor to traverse the code AST (abstract syntax tree).
Any code object that has an owning context.
The default implementation of CodeLanguage (for Java).
A Tag of HTML or XML.
TODO: this class ...