Class CodeName

java.lang.Object
io.github.mmm.code.api.CodeName

public final class CodeName extends Object
Represents a parsed hierarchical name like a qualified name or a part of it (e.g. "code.api.CodeName" as part of "net.sf.mmm.code.api.CodeName").
See Also:
  • Constructor Details

    • CodeName

      public CodeName(String qualifiedName, char separator)
      The constructor.
      Parameters:
      qualifiedName - the qualified name.
      separator - the package separator.
  • Method Details

    • getSimpleName

      public String getSimpleName()
      Returns:
      the simple name.
    • getFullName

      public String getFullName()
      Returns:
      the full name as the full name of the potential parent with the simple name appended separated by the separator char.
    • getParent

      public CodeName getParent()
      Returns:
      the parent CodeName or null if this is the root.
    • toString

      public String toString()
      Overrides:
      toString in class Object