Uses of Interface
io.github.mmm.code.api.annotation.CodeAnnotation
Packages that use CodeAnnotation
-
Uses of CodeAnnotation in io.github.mmm.code.api.annotation
Subinterfaces with type arguments of type CodeAnnotation in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeMutableItemWithTypethat represents anAnnotationinstance.interfaceCodeNodeItemContainerHierarchicalcontainingCodeAnnotations.Methods in io.github.mmm.code.api.annotation that return CodeAnnotationModifier and TypeMethodDescriptionCodeAnnotation.copy()CodeAnnotation.copy(CodeCopyMapper mapper) CodeAnnotations.getDeclared(CodeType type) default CodeAnnotationCodeAnnotations.getDeclaredOrAdd(CodeType type) Methods in io.github.mmm.code.api.annotation that return types with arguments of type CodeAnnotationModifier and TypeMethodDescriptionIterable<? extends CodeAnnotation> CodeAnnotations.getAll()Attention:
This method can be expensive as it has to traverse inherited elements.Methods in io.github.mmm.code.api.annotation with parameters of type CodeAnnotation -
Uses of CodeAnnotation in io.github.mmm.code.api.object
Methods in io.github.mmm.code.api.object with parameters of type CodeAnnotationModifier and TypeMethodDescriptionprotected voidCodeVisitor.visitAnnotation(CodeAnnotation annotation)