Interface CodeException
- All Superinterfaces:
CodeElement, CodeElementWithDeclaringType, CodeItem, CodeItemWithComment, CodeItemWithDeclaringType, CodeItemWithType, CodeMergeableItem<CodeException>, CodeMutable, CodeMutableItem, CodeMutableItemWithComment, CodeMutableItemWithType, CodeNode, CodeNodeItem, CodeNodeItemCopyable<CodeExceptions, CodeException>, CodeNodeItemWithDeclaringOperation, CodeOperationArg, CodeSimpleMergeableItem<CodeException>, CodeWithContext
public interface CodeException
extends CodeOperationArg, CodeSimpleMergeableItem<CodeException>, CodeNodeItemCopyable<CodeExceptions, CodeException>
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
- See Also:
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeElement
getAnnotations, getDoc, removeFromParentMethods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface CodeItemWithComment
getCommentMethods inherited from interface CodeItemWithDeclaringType
getDeclaringTypeMethods inherited from interface CodeItemWithType
getTypeMethods inherited from interface CodeMutable
isImmutable, isMutableMethods inherited from interface CodeMutableItem
setImmutableMethods inherited from interface CodeMutableItemWithComment
setCommentMethods inherited from interface CodeMutableItemWithType
setTypeMethods inherited from interface CodeNodeItemCopyable
copy, getParentMethods inherited from interface CodeNodeItemWithDeclaringOperation
getDeclaringOperationMethods inherited from interface CodeSimpleMergeableItem
merge, mergeMethods inherited from interface CodeWithContext
getContext, getSource
-
Method Details
-
getReflectiveObject
AnnotatedType getReflectiveObject()- Specified by:
getReflectiveObjectin interfaceCodeMutableItem- Returns:
- the optional reflective object of this item such as
Class. May benull(e.g. if this object was created from source-code only or has been created dynamically). However, if available it can be helpful for analysis especially in case of type-safeAnnotationprocessing. In most cases the generic type will be derived fromAnnotatedElementbut in specific cases it can also beProtectionDomainor other types that have no common parent-type. Therefore this generic type is unbounded here.
-
copy
CodeException copy()- Specified by:
copyin interfaceCodeElement- Specified by:
copyin interfaceCodeElementWithDeclaringType- Specified by:
copyin interfaceCodeMutableItem- Specified by:
copyin interfaceCodeNodeItem- Specified by:
copyin interfaceCodeNodeItemCopyable<CodeExceptions, CodeException>- Returns:
- a new
mutablecopy of thisCodeMutableItem. Will be a deep-copy with copies of all childCodeMutableItems.
-