Uses of Interface
io.github.mmm.code.api.CodePathElement
Packages that use CodePathElement
-
Uses of CodePathElement in io.github.mmm.code.api
Subinterfaces of CodePathElement in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).Subinterfaces with type arguments of type CodePathElement in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceMethods in io.github.mmm.code.api that return CodePathElementMethods in io.github.mmm.code.api that return types with arguments of type CodePathElementModifier and TypeMethodDescriptionList<? extends CodePathElement> CodePathElements.getDeclared()Attention:
This method can trigger expensive classpath scanning (or filesystem traversal) on its first call.Methods in io.github.mmm.code.api with parameters of type CodePathElementModifier and TypeMethodDescriptionvoidCodePathElements.add(CodePathElement child) Attention: This method is only for advanced usage.