Uses of Interface
io.github.mmm.code.api.copy.CodeNodeItemCopyable
Packages that use CodeNodeItemCopyable
Package
Description
-
Uses of CodeNodeItemCopyable in io.github.mmm.code.api
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interface -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.annotation
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeMutableItemWithTypethat represents anAnnotationinstance.interfaceCodeNodeItemContainerHierarchicalcontainingCodeAnnotations. -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.arg
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceCodeOperationArgfor a parameter (argument) of aCodeOperation.interfaceinterfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.block
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.block -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.copy
Classes in io.github.mmm.code.api.copy with type parameters of type CodeNodeItemCopyableModifier and TypeInterfaceDescriptioninterfaceCodeNodeItemCopyable<P extends CodeNode, SELF extends CodeNodeItemCopyable<P,SELF>> -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.doc
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.doc -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.imports
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.importsModifier and TypeInterfaceDescriptioninterface -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.member
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationrepresenting a constructor of aCodeType.interfaceCodeMembersas a container for theCodeConstructors.interfaceCodeMemberfor a field of aCodeType.interfaceCodeMembersas a container for theCodeFields.interfaceCodeOperationthat represents a method of aCodeType.interfaceCodeMembersas a container for theCodeMethods.interfaceCodeMembersas a container for theCodePropertys.interfaceAbstract interface for a field of aCodeType. -
Uses of CodeNodeItemCopyable in io.github.mmm.code.api.type
Subinterfaces of CodeNodeItemCopyable in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceCodeNodeItemContainerHierarchicalcontaining the nestedCodeTypes.interfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeNodeItemContainerHierarchicalcontaining the super types of aCodeType.interfaceCodeElementrepresenting a type (similar toClass).interfaceCodeGenericTypeParameterswith generic bound toCodeGenericType.interfaceCodeGenericTyperepresenting a type variable.interfaceinterfaceCodeGenericTyperepresenting a type variable.