Interface CodeDocLink


public interface CodeDocLink
Represents a parsed link of a CodeDoc.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
See Also:
  • Method Details

    • getSimpleName

      String getSimpleName()
      Returns:
      the simple name of the linked type.
    • getQualifiedName

      String getQualifiedName()
      Returns:
      the qualified name of the linked type. May be null if unqualified name was given. In such case it has to be looked up via imports.
    • getAnchor

      String getAnchor()
      Returns:
      the optional linked anchor or null for none.
    • getMethodLink

      CodeDocMethodLink getMethodLink()
      Returns:
      the optional CodeDocMethodLink if the anchor is a method reference or null for none.
    • getText

      String getText()
      Returns:
      the text of the link.
    • getLinkedValue

      Object getLinkedValue()
      Returns:
      the resolved value or null if no value referenced or resolving failed. Should be only used for value tags.
    • getLinkedValueAsString

      default String getLinkedValueAsString()
      Returns:
      the linked value as String with fallback to getSimpleName() with optional anchor. Therefore never null.
    • getLinkUrl

      String getLinkUrl()
      Returns:
      the resolved URL of this link.