Uses of Interface
io.github.mmm.code.api.element.CodeElement
Packages that use CodeElement
Package
Description
-
Uses of CodeElement in io.github.mmm.code.api
Subinterfaces of CodeElement in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interface -
Uses of CodeElement in io.github.mmm.code.api.annotation
Subinterfaces with type arguments of type CodeElement in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeNodeItemContainerHierarchicalcontainingCodeAnnotations.Methods in io.github.mmm.code.api.annotation that return CodeElement -
Uses of CodeElement in io.github.mmm.code.api.arg
Subinterfaces of CodeElement in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceinterfaceACodeMutableItemWithTyperepresenting a argument of aCodeOperationsuch asCodeParameter,CodeExceptionorCodeReturn.interfaceCodeOperationArgfor a parameter (argument) of aCodeOperation.interfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeElement in io.github.mmm.code.api.doc
Subinterfaces with type arguments of type CodeElement in io.github.mmm.code.api.doc -
Uses of CodeElement in io.github.mmm.code.api.element
Subinterfaces of CodeElement in io.github.mmm.code.api.elementModifier and TypeInterfaceDescriptioninterfaceCodeElementthat has adeclaring type.interfaceCodeElementthat hasmodifiers.interfaceCodeElementthat has aname.interfaceCodeElementthat optionally hastype variables.Methods in io.github.mmm.code.api.element that return CodeElement -
Uses of CodeElement in io.github.mmm.code.api.language
Methods in io.github.mmm.code.api.language with parameters of type CodeElementModifier and TypeMethodDescriptionvoidAbstractCodeLanguage.writeElement(CodeElement element, Appendable sink, String newline, String defaultIndent, String currentIndent) -
Uses of CodeElement in io.github.mmm.code.api.member
Subinterfaces of CodeElement in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationrepresenting a constructor of aCodeType.interfaceCodeMemberfor a field of aCodeType.interfaceCodeElementWithModifiersrepresenting aMemberof aCodeTypethat is either aCodeOperationor aCodeField.interfaceCodeOperationthat represents a method of aCodeType.interfaceinterfaceAbstract interface for a field of aCodeType. -
Uses of CodeElement in io.github.mmm.code.api.object
Methods in io.github.mmm.code.api.object with parameters of type CodeElement -
Uses of CodeElement in io.github.mmm.code.api.type
Subinterfaces of CodeElement in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeElementrepresenting a type (similar toClass).interfaceinterfaceCodeGenericTyperepresenting a type variable.interfaceCodeGenericTyperepresenting a type variable.Subinterfaces with type arguments of type CodeElement in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeElementrepresenting a type (similar toClass).Methods in io.github.mmm.code.api.type that return CodeElementMethods in io.github.mmm.code.api.type with parameters of type CodeElementModifier and TypeMethodDescriptionCodeType.createParameterizedType(CodeElement parent) This method should only be called if this type actually hastype variables.