Interface CodeExpressionCondition
- All Superinterfaces:
CodeCondition, CodeExpression, CodeItem
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeExpression
evaluateMethods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, write
-
Method Details
-
getExpression
CodeExpression getExpression()- Returns:
- the actual
CodeExpressionwrapped as condition. Should not already be aCodeConditionsuch asCodeComparisonOperatorExpression. Further it shall not be aCodeExpressionthat can never result in a boolean value such as aCodeMethodInvocationwith amethodreturning aCodeGenericTypethat can not beassigned toa boolean type or aCodeNAryOperatorExpressionwith anoperatorthat is notboolean.
-