Interface CodeLambdaExpression
- All Superinterfaces:
CodeExpression, CodeFunction, CodeItem, CodeItemWithVariables, CodeMutable, CodeMutableItem, CodeNode, CodeNodeItem, CodeWithContext
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Modifier and TypeMethodDescriptiongetBody()If the body contains only a single statement that is not aCodeReturnStatementList<? extends CodeVariable> Methods inherited from interface CodeExpression
evaluateMethods inherited from interface CodeFunction
canHaveBody, setBodyMethods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface CodeItemWithVariables
getVariableMethods inherited from interface CodeMutable
isImmutable, isMutableMethods inherited from interface CodeMutableItem
getReflectiveObject, setImmutableMethods inherited from interface CodeNodeItem
copy, copyMethods inherited from interface CodeWithContext
getContext, getSource
-
Method Details
-
getVariables
List<? extends CodeVariable> getVariables()- Returns:
- the
ListofCodeVariables taken as input for the lambda. May beempty(for burger arrow function) but nevernull.
-
getBody
CodeBlockBody getBody()If the body contains only a single statement that is not aCodeReturnStatement- Specified by:
getBodyin interfaceCodeFunction- Returns:
- the
CodeBlockBodyof this function. May be empty (have nostatements) but nevernull.
-