Interface CodeVariable
- All Superinterfaces:
CodeExpression, CodeItem, CodeItemWithDeclaration, CodeItemWithName, CodeItemWithType
- All Known Subinterfaces:
CodeField, CodeLocalVariable, CodeParameter, CodeVariableThis
public interface CodeVariable
extends CodeExpression, CodeItemWithName, CodeItemWithType, CodeItemWithDeclaration
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Modifier and TypeMethodDescriptiondefault voidwriteReference(Appendable sink, boolean declaration, Boolean qualified) Internal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.Methods inherited from interface CodeExpression
evaluateMethods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface CodeItemWithDeclaration
writeReferenceMethods inherited from interface CodeItemWithName
getNameMethods inherited from interface CodeItemWithType
getType
-
Method Details
-
writeReference
default void writeReference(Appendable sink, boolean declaration, Boolean qualified) throws IOException Description copied from interface:CodeItemWithDeclarationInternal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.- Specified by:
writeReferencein interfaceCodeItemWithDeclaration- Parameters:
sink- theAppendablewhere toappendthe code from thisCodeItem.declaration-trueif used as a declaration,falseotherwise (for usage as reference).qualified-Boolean#TRUEto usequalified namefor type names,Boolean#FALSEto usesimple names, ornullto usequalified flag.- Throws:
IOException- if thrown byAppendable.
-