Interface CodeImport

All Superinterfaces:
CodeItem

public interface CodeImport extends CodeItem
CodeItem representing an import.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • getReference

      String getReference()
      Returns:
      the reference pointing to the location where to import from. For Java typically the qualified name of the according type. May also be a star import but these are discouraged.
    • isStatic

      boolean isStatic()
      Returns:
      true if this is a static import, false otherwise.
    • getItems

      List<CodeImportItem> getItems()
      Returns:
      the List of items to import from the reference. Will be empty for no item and therefore is never null. For Java this will always be empty.