Interface CodeItemWithDeclaration
- All Superinterfaces:
CodeItem
- All Known Subinterfaces:
CodeArrayType, CodeComposedType, CodeField, CodeGenericType, CodeLocalVariable, CodeParameter, CodeParameterizedType, CodeType, CodeTypePlaceholder, CodeTypeVariable, CodeTypeWildcard, CodeVariable, CodeVariableThis
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Modifier and TypeMethodDescriptiondefault voidwriteReference(Appendable sink, boolean declaration) Internal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.voidwriteReference(Appendable sink, boolean declaration, Boolean qualified) Internal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, write
-
Method Details
-
writeReference
Internal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.- Parameters:
sink- theAppendablewhere toappendthe code from thisCodeItem.declaration-trueif used as a declaration,falseotherwise (for usage as reference).- Throws:
IOException- if thrown byAppendable.
-
writeReference
Internal variant ofCodeItem.write(Appendable)to write a reference for the usage of this item.- Parameters:
sink- theAppendablewhere toappendthe code from thisCodeItem.declaration-trueif used as a declaration,falseotherwise (for usage as reference).qualified-Boolean#TRUEto usequalified namefor type names,Boolean#FALSEto usesimple names, ornullto usequalified flag.- Throws:
IOException- if thrown byAppendable.
-