Interface CodeItemWithQualifiedFlag

All Superinterfaces:
CodeItem
All Known Subinterfaces:
CodeArrayType, CodeComposedType, CodeConstructorInvocation, CodeGenericType, CodeParameterizedType, CodeType, CodeTypePlaceholder, CodeTypeVariable, CodeTypeWildcard

public interface CodeItemWithQualifiedFlag extends CodeItem
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • isQualified

      boolean isQualified()
      Returns:
      true if the usage of this item in its place is fully qualified, false otherwise (if the simple name shall be used what is the default).