Interface CodeMutableItemWithQualifiedName

All Superinterfaces:
CodeItem, CodeItemWithQualifiedName, CodeItemWithQualifiedNameAndParentPackage, CodeMutable, CodeMutableItem
All Known Subinterfaces:
CodeType

public interface CodeMutableItemWithQualifiedName extends CodeMutableItem, CodeItemWithQualifiedNameAndParentPackage
CodeItem that has a simple name and a qualified name, that is qualified via the parent package.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • setSimpleName

      void setSimpleName(String simpleName)
      Parameters:
      simpleName - the new simple name.
      Throws:
      io.github.mmm.base.exception.ReadOnlyException - if immutable.
    • setParentPackage

      void setParentPackage(CodePackage parentPackage)
      Parameters:
      parentPackage - the new parent package.
      Throws:
      io.github.mmm.base.exception.ReadOnlyException - if immutable.