Uses of Interface
io.github.mmm.code.api.item.CodeItemWithComment
Packages that use CodeItemWithComment
Package
Description
-
Uses of CodeItemWithComment in io.github.mmm.code.api
Subinterfaces of CodeItemWithComment in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interface -
Uses of CodeItemWithComment in io.github.mmm.code.api.annotation
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeMutableItemWithTypethat represents anAnnotationinstance. -
Uses of CodeItemWithComment in io.github.mmm.code.api.arg
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceinterfaceACodeMutableItemWithTyperepresenting a argument of aCodeOperationsuch asCodeParameter,CodeExceptionorCodeReturn.interfaceCodeOperationArgfor a parameter (argument) of aCodeOperation.interfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeItemWithComment in io.github.mmm.code.api.element
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.elementModifier and TypeInterfaceDescriptioninterfaceinterfaceCodeElementthat has adeclaring type.interfaceCodeElementthat hasmodifiers.interfaceCodeElementthat has aname.interfaceCodeElementthat optionally hastype variables. -
Uses of CodeItemWithComment in io.github.mmm.code.api.item
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.itemModifier and TypeInterfaceDescriptioninterface -
Uses of CodeItemWithComment in io.github.mmm.code.api.member
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationrepresenting a constructor of aCodeType.interfaceCodeMemberfor a field of aCodeType.interfaceCodeElementWithModifiersrepresenting aMemberof aCodeTypethat is either aCodeOperationor aCodeField.interfaceCodeOperationthat represents a method of aCodeType.interfaceinterfaceAbstract interface for a field of aCodeType. -
Uses of CodeItemWithComment in io.github.mmm.code.api.type
Subinterfaces of CodeItemWithComment in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeElementrepresenting a type (similar toClass).interfaceinterfaceCodeGenericTyperepresenting a type variable.interfaceCodeGenericTyperepresenting a type variable.