Uses of Interface
io.github.mmm.code.api.item.CodeItemWithQualifiedName
Packages that use CodeItemWithQualifiedName
Package
Description
-
Uses of CodeItemWithQualifiedName in io.github.mmm.code.api
Subinterfaces of CodeItemWithQualifiedName in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interface -
Uses of CodeItemWithQualifiedName in io.github.mmm.code.api.item
Subinterfaces of CodeItemWithQualifiedName in io.github.mmm.code.api.itemModifier and TypeInterfaceDescriptioninterfaceCodeItemWithQualifiedNamethat has aparent package.interface -
Uses of CodeItemWithQualifiedName in io.github.mmm.code.api.language
Methods in io.github.mmm.code.api.language with parameters of type CodeItemWithQualifiedNameModifier and TypeMethodDescriptionAbstractCodeLanguage.verifySimpleName(CodeItemWithQualifiedName item, String simpleName) CodeLanguage.verifySimpleName(CodeItemWithQualifiedName item, String simpleName) -
Uses of CodeItemWithQualifiedName in io.github.mmm.code.api.type
Subinterfaces of CodeItemWithQualifiedName in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeElementrepresenting a type (similar toClass).interfaceinterfaceCodeGenericTyperepresenting a type variable.interfaceCodeGenericTyperepresenting a type variable.