Uses of Interface
io.github.mmm.code.api.item.CodeMutableItemWithComment
Packages that use CodeMutableItemWithComment
Package
Description
-
Uses of CodeMutableItemWithComment in io.github.mmm.code.api
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interface -
Uses of CodeMutableItemWithComment in io.github.mmm.code.api.annotation
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeMutableItemWithTypethat represents anAnnotationinstance. -
Uses of CodeMutableItemWithComment in io.github.mmm.code.api.arg
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceinterfaceACodeMutableItemWithTyperepresenting a argument of aCodeOperationsuch asCodeParameter,CodeExceptionorCodeReturn.interfaceCodeOperationArgfor a parameter (argument) of aCodeOperation.interfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeMutableItemWithComment in io.github.mmm.code.api.element
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.api.elementModifier and TypeInterfaceDescriptioninterfaceinterfaceCodeElementthat has adeclaring type.interfaceCodeElementthat hasmodifiers.interfaceCodeElementthat has aname.interfaceCodeElementthat optionally hastype variables. -
Uses of CodeMutableItemWithComment in io.github.mmm.code.api.member
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationrepresenting a constructor of aCodeType.interfaceCodeMemberfor a field of aCodeType.interfaceCodeElementWithModifiersrepresenting aMemberof aCodeTypethat is either aCodeOperationor aCodeField.interfaceCodeOperationthat represents a method of aCodeType.interfaceinterfaceAbstract interface for a field of aCodeType. -
Uses of CodeMutableItemWithComment in io.github.mmm.code.api.type
Subinterfaces of CodeMutableItemWithComment in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeElementrepresenting a type (similar toClass).interfaceinterfaceCodeGenericTyperepresenting a type variable.interfaceCodeGenericTyperepresenting a type variable.