Uses of Package
io.github.mmm.code.api.item
Packages that use io.github.mmm.code.api.item
Package
Description
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.apiClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemWithQualifiedNamethat has aparent package. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.annotationClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemthat has ageneric type.CodeMutableItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.argClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemrepresenting a declaration.CodeNodeItemthat has adeclaring type.CodeItemthat has ageneric type.CodeMutableItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.blockClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.commentClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.copyClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.docClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.elementClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeNodeItemthat has adeclaring type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.expressionClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemrepresenting a declaration.CodeItemthat has aqualified flag.CodeItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.importsClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.itemClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemWithQualifiedNamethat has aparent package.CodeItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.languageClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.memberClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemrepresenting a declaration.CodeNodeItemthat has adeclaring type.CodeItemthat has ageneric type.CodeMutableItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.mergeClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.nodeClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeNodeItemthat has adeclaring type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.operatorClassDescriptionAbstract top-level interface for any item of code as defined by this API.
-
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.statementClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemrepresenting a declaration.CodeItemthat has ageneric type. -
Classes in io.github.mmm.code.api.item used by io.github.mmm.code.api.typeClassDescriptionAbstract top-level interface for any item of code as defined by this API.
CodeItemrepresenting a declaration.CodeNodeItemthat has adeclaring type.CodeItemthat has aqualified flag.CodeItemWithQualifiedNamethat has aparent package.CodeItemthat has ageneric type.CodeMutableItemthat has ageneric type.