Interface CodeProperties

All Superinterfaces:
CodeItem, CodeItemWithDeclaringType, CodeMembers<CodeProperty>, CodeMutable, CodeMutableItem, CodeNode, CodeNodeContainer<CodeProperty>, CodeNodeItem, CodeNodeItemContainer<CodeProperty>, CodeNodeItemContainerHierarchical<CodeProperty>, CodeNodeItemContainerHierarchicalWithName<CodeProperty>, CodeNodeItemContainerWithName<CodeProperty>, CodeNodeItemCopyable<CodeType, CodeProperties>, CodeWithContext, Iterable<CodeProperty>

CodeMembers as a container for the CodePropertys.
Attention:
The properties are calculated on the fly and the operations may be expensive. Avoid subsequent calls to the same method if possible.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)