Uses of Interface
io.github.mmm.code.api.member.CodeMethod
Packages that use CodeMethod
Package
Description
-
Uses of CodeMethod in io.github.mmm.code.api
Methods in io.github.mmm.code.api that return CodeMethodModifier and TypeMethodDescriptionCodeFactory.createGetter(CodeType type, String propertyName, CodeGenericType propertyType, boolean implement, String... doc) CodeFactory.createMethod(CodeMethods parent, String name, Method reflectiveObject) CodeFactory.createSetter(CodeType type, String propertyName, CodeGenericType propertyType, boolean implement, String... doc) -
Uses of CodeMethod in io.github.mmm.code.api.arg
Subinterfaces with type arguments of type CodeMethod in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeMethod in io.github.mmm.code.api.expression
Methods in io.github.mmm.code.api.expression that return CodeMethod -
Uses of CodeMethod in io.github.mmm.code.api.language
Methods in io.github.mmm.code.api.language with parameters of type CodeMethodModifier and TypeMethodDescriptionprotected CodeModifiersAbstractCodeLanguage.getMethodModifiers(CodeMethod method) voidAbstractCodeLanguage.writeMethod(CodeMethod method, Appendable sink, String newline, String defaultIndent, String currentIndent) voidCodeLanguage.writeMethod(CodeMethod method, Appendable sink, String newline, String defaultIndent, String currentIndent) Writes the given method (e.g. -
Uses of CodeMethod in io.github.mmm.code.api.member
Subinterfaces with type arguments of type CodeMethod in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationthat represents a method of aCodeType.interfaceCodeOperationthat represents a method of aCodeType.interfaceCodeMembersas a container for theCodeMethods.interfaceCodeMembersas a container for theCodeMethods.Methods in io.github.mmm.code.api.member that return CodeMethodModifier and TypeMethodDescriptionCodeMethod.copy()CodeMethods.getDeclared(String name, CodeGenericType... parameterTypes) default CodeMethoddefault CodeMethodCodeMethods.getFirstOrCreate(String name) CodeField.getGetter()CodeProperty.getGetter()CodeField.getOrCreateGetter()CodeField.getOrCreateSetter()CodeMethod.getParentMethod()Attention:
This method is expensive as it has to traverse all methods of the entire type hierarchy recursively.CodeField.getSetter()CodeProperty.getSetter() -
Uses of CodeMethod in io.github.mmm.code.api.object
Methods in io.github.mmm.code.api.object with parameters of type CodeMethod