Interface CodeMergeStrategyDecider

All Known Implementing Classes:
CodeMergeStrategyDeciderDefault
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface CodeMergeStrategyDecider
Call-back Interface to decide which merge strategy to apply for a merge. Will be called recursively during the merge except for CodeNodeItemContainers.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)