Interface CodeMergeableItem<S extends CodeMergeableItem<S>>

Type Parameters:
S - type of the item that can be merged with this item. Will typically be this type itself.
All Superinterfaces:
CodeItem
All Known Subinterfaces:
CodeAdvancedMergeableItem<S>, CodeAnnotations, CodeConstructor, CodeConstructors, CodeDoc, CodeException, CodeExceptions, CodeField, CodeFields, CodeMethod, CodeMethods, CodeNestedTypes, CodeParameter, CodeParameters, CodeReturn, CodeSimpleMergeableItem<S>, CodeSuperTypes, CodeType, CodeTypeVariables

public interface CodeMergeableItem<S extends CodeMergeableItem<S>> extends CodeItem
CodeItem with merge support.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • merge

      S merge(S other)
      Parameters:
      other - the other item to merge.
      Returns:
      the result of the merge. May be this item where the merge was invoked on, or the given other item.