Interface CodeSimpleMergeableItem<S extends CodeSimpleMergeableItem<S>>

Type Parameters:
S - type of the item that can be merged with this item. Will typically be this type itself.
All Superinterfaces:
CodeItem, CodeMergeableItem<S>
All Known Subinterfaces:
CodeAnnotations, CodeDoc, CodeException, CodeExceptions, CodeParameter, CodeParameters, CodeReturn, CodeSuperTypes, CodeTypeVariables

public interface CodeSimpleMergeableItem<S extends CodeSimpleMergeableItem<S>> extends CodeMergeableItem<S>
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • merge

      default S merge(S other)
      Specified by:
      merge in interface CodeMergeableItem<S extends CodeSimpleMergeableItem<S>>
      Parameters:
      other - the other item to merge.
      Returns:
      the result of the merge. May be this item where the merge was invoked on, or the given other item.
    • merge

      S merge(S other, CodeMergeStrategy strategy)
      Parameters:
      other - the other item to merge.
      strategy - true to override, false otherwise (regular merge, default).
      Returns:
      the result of the merge. May be this item where the merge was invoked on, or the given other item.