Interface CodeNodeWithFileWriting

All Superinterfaces:
CodeNode, CodeWithContext
All Known Subinterfaces:
CodeFile, CodePackage, CodeSource

public interface CodeNodeWithFileWriting extends CodeNode
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    write(Path targetFolder)
    Recursively writes the source code of this item recursively with all its children to the folder identified by the given Path.
    void
    write(Path targetFolder, Charset encoding)
    Recursively writes the source code of this item recursively with all its children to the folder identified by the given Path.

    Methods inherited from interface CodeNode

    getParent

    Methods inherited from interface CodeWithContext

    getContext, getSource
  • Method Details

    • write

      void write(Path targetFolder)
      Recursively writes the source code of this item recursively with all its children to the folder identified by the given Path.
      Parameters:
      targetFolder - the Path pointing to the folder where to write the content of the given CodePackage.
    • write

      void write(Path targetFolder, Charset encoding)
      Recursively writes the source code of this item recursively with all its children to the folder identified by the given Path.
      Parameters:
      targetFolder - the Path pointing to the folder where to write the content of the given CodePackage.
      encoding - the Charset used to encode the characters in the file.