Uses of Interface
io.github.mmm.code.api.object.CodeMutable
Packages that use CodeMutable
Package
Description
-
Uses of CodeMutable in io.github.mmm.code.api
Subinterfaces of CodeMutable in io.github.mmm.code.apiModifier and TypeInterfaceDescriptioninterfaceAbstract top-level interface for any item of code as defined by this API.interfaceCodeElementrepresenting aPackage(or similar namespace concept in case of other language).interfaceinterface -
Uses of CodeMutable in io.github.mmm.code.api.annotation
Subinterfaces of CodeMutable in io.github.mmm.code.api.annotationModifier and TypeInterfaceDescriptioninterfaceCodeMutableItemWithTypethat represents anAnnotationinstance.interfaceCodeNodeItemContainerHierarchicalcontainingCodeAnnotations. -
Uses of CodeMutable in io.github.mmm.code.api.arg
Subinterfaces of CodeMutable in io.github.mmm.code.api.argModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceACodeMutableItemWithTyperepresenting a argument of aCodeOperationsuch asCodeParameter,CodeExceptionorCodeReturn.interfaceCodeOperationArgs<A extends CodeOperationArg>interfaceCodeOperationArgfor a parameter (argument) of aCodeOperation.interfaceinterfaceCodeOperationArgfor the returned result of aCodeMethod. -
Uses of CodeMutable in io.github.mmm.code.api.block
Subinterfaces of CodeMutable in io.github.mmm.code.api.blockModifier and TypeInterfaceDescriptioninterfaceCodeStatementfor a block that groups multiplestatements.interfaceinterfaceinterfaceCodeBlockfor anforblock.interfaceCodeBlockfor anifblock.interfaceinterfaceCodeBlockthat is a regularCodeStatement.interfaceinterface -
Uses of CodeMutable in io.github.mmm.code.api.copy
Subinterfaces of CodeMutable in io.github.mmm.code.api.copyModifier and TypeInterfaceDescriptioninterfaceCodeNodeItemCopyable<P extends CodeNode, SELF extends CodeNodeItemCopyable<P,SELF>> -
Uses of CodeMutable in io.github.mmm.code.api.doc
Subinterfaces of CodeMutable in io.github.mmm.code.api.doc -
Uses of CodeMutable in io.github.mmm.code.api.element
Subinterfaces of CodeMutable in io.github.mmm.code.api.elementModifier and TypeInterfaceDescriptioninterfaceinterfaceCodeElementthat has adeclaring type.interfaceCodeElementthat hasmodifiers.interfaceCodeElementthat has aname.interfaceCodeElementthat optionally hastype variables. -
Uses of CodeMutable in io.github.mmm.code.api.expression
Subinterfaces of CodeMutable in io.github.mmm.code.api.expressionModifier and TypeInterfaceDescriptioninterfaceCodeExpressionrepresenting a lambda function.
Syntax: -
Uses of CodeMutable in io.github.mmm.code.api.imports
Subinterfaces of CodeMutable in io.github.mmm.code.api.importsModifier and TypeInterfaceDescriptioninterface -
Uses of CodeMutable in io.github.mmm.code.api.item
Subinterfaces of CodeMutable in io.github.mmm.code.api.itemModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeMutableItemthat has ageneric type. -
Uses of CodeMutable in io.github.mmm.code.api.member
Subinterfaces of CodeMutable in io.github.mmm.code.api.memberModifier and TypeInterfaceDescriptioninterfaceCodeOperationrepresenting a constructor of aCodeType.interfaceCodeMembersas a container for theCodeConstructors.interfaceCodeMemberfor a field of aCodeType.interfaceCodeMembersas a container for theCodeFields.interfaceCodeElementWithModifiersrepresenting aMemberof aCodeTypethat is either aCodeOperationor aCodeField.interfaceCodeMembers<M extends CodeMember>CodeItemthat groups allCodeMembers of a type.interfaceCodeOperationthat represents a method of aCodeType.interfaceCodeMembersas a container for theCodeMethods.interfaceinterfaceCodeOperations<O extends CodeOperation>CodeMembersas a container for theCodeOperations.interfaceCodeMembersas a container for theCodePropertys.interfaceAbstract interface for a field of aCodeType. -
Uses of CodeMutable in io.github.mmm.code.api.node
Subinterfaces of CodeMutable in io.github.mmm.code.api.nodeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceCodeNodeItemContainer<I extends CodeItem>interfaceCodeNodeItemContainerFlat<I extends CodeItem>interfaceCodeNodeItemContainerFlatWithName<I extends CodeItem>interfaceCodeNodeItemContainerHierarchical<I extends CodeItem>interfaceinterfaceCodeNodeItemContainerWithName<I extends CodeItem>interfaceCodeNodeItemthat has adeclaring member. -
Uses of CodeMutable in io.github.mmm.code.api.source
Subinterfaces of CodeMutable in io.github.mmm.code.api.sourceModifier and TypeInterfaceDescriptioninterface -
Uses of CodeMutable in io.github.mmm.code.api.type
Subinterfaces of CodeMutable in io.github.mmm.code.api.typeModifier and TypeInterfaceDescriptioninterfaceinterfaceinterfaceinterfaceCodeGenericTypeParameters<P extends CodeGenericType>interfaceCodeNodeItemContainerHierarchicalcontaining the nestedCodeTypes.interfaceCodeGenericTyperepresenting a parameterized type.interfaceCodeNodeItemContainerHierarchicalcontaining the super types of aCodeType.interfaceCodeElementrepresenting a type (similar toClass).interfaceCodeGenericTypeParameterswith generic bound toCodeGenericType.interfaceinterfaceCodeGenericTyperepresenting a type variable.interfaceinterfaceCodeGenericTyperepresenting a type variable.