Interface CodeNAryBooleanOperator

All Superinterfaces:
CodeItem, CodeNAryOperator, CodeOperator
All Known Subinterfaces:
CodeNAryHybridOperator

public interface CodeNAryBooleanOperator extends CodeNAryOperator
CodeNAryOperator that takes boolean arguments and has a boolean result. Except for instances of CodeNAryHybridOperator other types of arguments and result are not supported.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)