Interface CodeNAryHybridOperator
- All Superinterfaces:
CodeItem, CodeNAryBooleanOperator, CodeNAryNumericOperator, CodeNAryOperator, CodeOperator
- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringNameof bitwise AND operator (can technically be applied to boolean values in Java but this is discouraged).static final StringNameof bitwise OR operator (can technically be applied to boolean values in Java but this is discouraged).static final StringNameof (bitwise) XOR operator (can be applied to boolean values in Java - has to be wrapped as aCodeConditionthen).Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINEFields inherited from interface CodeNAryBooleanOperator
NAME_AND, NAME_ORFields inherited from interface CodeNAryNumericOperator
NAME_DIV, NAME_MOD, NAME_MUL, NAME_SHIFT_LEFT, NAME_SHIFT_RIGHT_SIGNED, NAME_SHIFT_RIGHT_UNSIGNED, NAME_SUB -
Method Summary
Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface CodeNAryBooleanOperator
isBooleanMethods inherited from interface CodeNAryNumericOperator
isNumericMethods inherited from interface CodeNAryOperator
isNAryMethods inherited from interface CodeOperator
getName, isComparison, isUnary
-
Field Details
-
NAME_BIT_OR
-
NAME_BIT_AND
-
NAME_XOR
Nameof (bitwise) XOR operator (can be applied to boolean values in Java - has to be wrapped as aCodeConditionthen).- See Also:
-