Interface CodeNAryNumericOperator

All Superinterfaces:
CodeItem, CodeNAryOperator, CodeOperator
All Known Subinterfaces:
CodeNAryArbitraryOperator, CodeNAryHybridOperator

public interface CodeNAryNumericOperator extends CodeNAryOperator
CodeNAryOperator that takes numeric arguments and in such case has a numeric result. Except for instances of CodeNAryArbitraryOperator other types of arguments and result are not supported.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)