Interface CodeNAryOperator

All Superinterfaces:
CodeItem, CodeOperator
All Known Subinterfaces:
CodeNAryArbitraryOperator, CodeNAryBooleanOperator, CodeNAryHybridOperator, CodeNAryNumericOperator

public interface CodeNAryOperator extends CodeOperator
CodeOperator that is N-ary. It takes two or more arguments.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • isNAry

      default boolean isNAry()
      Specified by:
      isNAry in interface CodeOperator
      Returns:
      true if this is a CodeNAryOperator that takes two or more arguments to perform a calculation, false otherwise.
    • isBoolean

      boolean isBoolean()
      Returns:
      true if CodeNAryBooleanOperator, false otherwise. If false the result can never be a boolean value.
    • isNumeric

      boolean isNumeric()
      Returns:
      true if CodeNAryNumericOperator, false otherwise. If false the result can never be a numeric value.