Interface CodeOperator

All Superinterfaces:
CodeItem
All Known Subinterfaces:
CodeComparisonOperator, CodeNAryArbitraryOperator, CodeNAryBooleanOperator, CodeNAryHybridOperator, CodeNAryNumericOperator, CodeNAryOperator, CodeUnaryOperator

public interface CodeOperator extends CodeItem
CodeItem for an operator symbol.
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)
  • Method Details

    • getName

      String getName()
      Returns:
      the name of this operator.
    • isUnary

      boolean isUnary()
      Returns:
      true if this is a CodeUnaryOperator that takes exactly one argument, false otherwise.
    • isComparison

      boolean isComparison()
      Returns:
      true if this is a CodeComparisonOperator that takes exactly two arguments to compare, false otherwise.
    • isNAry

      boolean isNAry()
      Returns:
      true if this is a CodeNAryOperator that takes two or more arguments to perform a calculation, false otherwise.