Package io.github.mmm.code.api
package io.github.mmm.code.api
-
ClassDescriptionA
CodeContextis the main entry point of this API.This is a low-level factory for code objects.Abstract top-level interface for any item of code as defined by this API.Abstract interface to get (or load)types.Represents a parsed hierarchical name like aqualified nameor a part of it (e.g.CodeElementrepresenting aPackage(or similar namespace concept in case of other language).Abstract interface used to retrieveCodePackages andCodeTypes.Any code object that has an owningcontext.