All Classes and Interfaces
Class
Description
Implementation of
CodeCopyMapper for default mapping (copy only children).The default implementation of
CodeLanguage (for Java).CodeMutableItemWithType that represents an Annotation instance.CodeNodeItemContainerHierarchical containing CodeAnnotations.CodeExpression for an array instatiation.Syntax example:
An atomic
CodeStatement (unlike a CodeBlock).CodeStatement for a block that groups multiple statements.CodeComment representing a multi-line comment.CodeBlock for an for block.CodeBlock for an if block.CodeBlock that is a regular CodeStatement.CodeStatement for a comment.CodeComment representing a sequence of CodeComments.CodeOperator for comparison expressions.CodeOperatorExpression for a CodeComparisonOperator expression.CodeExpression representing a condition.CodeExpression for a constant value.CodeOperation representing a constructor of a CodeType.CodeMembers as a container for the CodeConstructors.CodeNode as common anchestor of
CodePackage and
CodeSource.A
CodeContext is the main entry point of this API.Implementation of
CodeCopyMapper for default mapping (copy only children).Enum with the available types defining the relation of a CodeNodeItem to
map to the
CodeNodeItem to
copy.CodeItem representing API documentation (e.g.Definition of format(s) to be able to convert
CodeDoc to.Represents a parsed link of a
CodeDoc.Represents a method reference for a
CodeDocLink.CodeElement that has a declaring type.CodeElement that has modifiers.CodeElement that has a name.CodeElement that optionally has type variables.CodeItem for an expression.This is a low-level factory for code objects.
CodeMember for a field of a CodeType.CodeMembers as a container for the CodeFields.Abstract top-level interface for any item of code as defined by this API.
CodeForExpression for a foreach loop.CodeForExpression for a regular for loop.CodeItem representing an import.TODO hohwille This type ...
An item of a
CodeImport as used in type-scrypt (ES6).CodeComment representing an inline comment.Abstract top-level interface for any item of code as defined by this API.
CodeItem representing a declaration.CodeNodeItem that has a declaring type.CodeItem that has a qualified flag.CodeItemWithQualifiedName that has a parent package.CodeItem that has a generic type.CodeExpression representing a lambda function.Syntax:
Interface to abstract from a concrete language.
CodeConstant representing a literal value.Abstract interface to get (or load)
types.CodeAtomicStatement to declare multiple CodeLocalVariables in a single statement.CodeElementWithModifiers representing a Member of a
CodeType that is either a CodeOperation or a CodeField.CodeItem that groups all CodeMembers of a type.Enum with the available strategies for a
merge.Implementation of
CodeMergeStrategyDecider that will always decide to merge but overrides the body if a @Generated annotation is
present and otherwise keeps the original body.CodeOperation that represents a method of a CodeType.CodeMembers as a container for the CodeMethods.Represents the visibility of a
CodeMethod.CodeMutableItem that has a generic type.Represents a parsed hierarchical name like a
qualified name or a part of it (e.g.CodeNAryOperator that takes boolean arguments and has a boolean result.CodeOperator that is N-ary.CodeOperatorExpression using a CodeNAryOperator.CodeNodeItemContainerHierarchical containing the nested CodeTypes.A node of the abstract syntax tree (AST) that is connected with its
parent.CodeItemWithDeclaringType that has a declaring element.CodeNodeItem that has a declaring member.CodeItemWithDeclaringType that has an optional declaring
operation.CodeItem with file writing support.A
CodeMutableItemWithType representing a argument of a CodeOperation such as
CodeParameter, CodeException or CodeReturn.CodeExpression representing the invocation of a CodeOperation.CodeMembers as a container for the CodeOperations.CodeItem for an operator symbol.CodeElement representing a Package (or similar namespace concept in case of other language).CodeOperationArg for a parameter (argument) of a CodeOperation.CodeGenericType representing a parameterized type.CodeMembers as a container for the CodePropertys.Abstract interface for a field of a
CodeType.Abstract interface used to retrieve
CodePackages and CodeTypes.CodeOperationArg for the returned result of a CodeMethod.CodeAtomicStatement returning the result of an expression.CodeMergeableItem withCodeSingleComment representing a single-line comment.CodeNodeContainer containing CodeSources.Descriptor with details of a
CodeSource.CodeNodeItemContainerHierarchical containing the super types of a CodeType.CodeExpression for a ternary expression.CodeElement representing a type (similar to Class).CodeGenericTypeParameters with generic bound to CodeGenericType.CodeGenericType representing a type variable.CodeGenericType representing a type variable.CodeOperator that is unary and takes exactly one single argument.CodeOperatorExpression using a CodeUnaryOperator.CodeVariable for the surrounding instance.Represents the visibility of a
CodeMethod.Generic visitor to traverse the code AST (abstract syntax tree).
Any code object that has an owning
context.The default implementation of
CodeLanguage (for Java).A
Tag of HTML or XML.TODO: this class ...