Class CodeDocFormat
java.lang.Object
io.github.mmm.code.api.doc.CodeDocFormat
- Direct Known Subclasses:
CodeDocFormat.CodeDocFormatAsciiDoc, CodeDocFormat.CodeDocFormatHtml, CodeDocFormat.CodeDocFormatPlainText, CodeDocFormat.CodeDocFormatRaw
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionprotected static classCodeDocFormatforASCII_DOC.protected static classCodeDocFormatforHTML.protected static classCodeDocFormatforPLAIN_TEXT.protected static classCodeDocFormatforRAW. -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final CodeDocFormatCodeDocFormatfor documentation as AsciiDoc fragment.static final CodeDocFormatCodeDocFormatfor documentation as HTML fragment.static final CodeDocFormatCodeDocFormatfor documentation as plain text (all markup removed).static final CodeDocFormatCodeDocFormatfor documentation as raw text in its original source format (e.g. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionabstract booleanabstract StringreplaceDocTag(String tag, Supplier<CodeDocLink> link, String text) abstract StringreplaceXmlTag(Tag tag) abstract StringtoString()
-
Field Details
-
HTML
CodeDocFormatfor documentation as HTML fragment. -
ASCII_DOC
CodeDocFormatfor documentation as AsciiDoc fragment. -
PLAIN_TEXT
CodeDocFormatfor documentation as plain text (all markup removed). -
RAW
CodeDocFormatfor documentation as raw text in its original source format (e.g. JavaDoc or JSDoc).
-
-
Constructor Details
-
CodeDocFormat
public CodeDocFormat()
-
-
Method Details
-
isReplaceXmlTags
public abstract boolean isReplaceXmlTags()- Returns:
trueif XML tags shall be parsed andreplaced,falseotherwise (if they shall be kept unmodified).
-
replaceXmlTag
-
replaceDocTag
- Parameters:
tag- the documentation tag such asCodeDoc.TAG_CODEorCodeDoc.TAG_LINK.link- the optionalSupplierused to resolve aCodeDocLinkin case oflink,linkplain, orvaluetag. Otherwisenull.text- the plain text.- Returns:
- the tag converted to this format.
-
toString
-