Interface CodeImport
- All Superinterfaces:
CodeItem
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, write
-
Method Details
-
getReference
String getReference()- Returns:
- the reference pointing to the location where to import from. For Java typically the
qualified nameof the according type. May also be a star import but these are discouraged.
-
isStatic
boolean isStatic()- Returns:
trueif this is a static import,falseotherwise.
-
getItems
-