Interface CodeItemWithQualifiedFlag
- All Superinterfaces:
CodeItem
- All Known Subinterfaces:
CodeArrayType, CodeComposedType, CodeConstructorInvocation, CodeGenericType, CodeParameterizedType, CodeType, CodeTypePlaceholder, CodeTypeVariable, CodeTypeWildcard
CodeItem that has a qualified flag.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, write
-
Method Details
-
isQualified
boolean isQualified()- Returns:
trueif the usage of this item in its place isfully qualified,falseotherwise (if thesimple nameshall be used what is the default).
-