the optional reflective object of this item such as Class. May be null (e.g. if this object
was created from source-code only or has been created dynamically). However, if available it can be helpful
for analysis especially in case of type-safe Annotation processing. In most
cases the generic type will be derived from AnnotatedElement but in specific
cases it can also be ProtectionDomain or other types that have no common parent-type.
Therefore this generic type is unbounded here.