Interface CodeSimpleMergeableItem<S extends CodeSimpleMergeableItem<S>>
- Type Parameters:
S- type of theitemthat can be merged with this item. Will typically be this type itself.
- All Superinterfaces:
CodeItem, CodeMergeableItem<S>
- All Known Subinterfaces:
CodeAnnotations, CodeDoc, CodeException, CodeExceptions, CodeParameter, CodeParameters, CodeReturn, CodeSuperTypes, CodeTypeVariables
public interface CodeSimpleMergeableItem<S extends CodeSimpleMergeableItem<S>>
extends CodeMergeableItem<S>
CodeMergeableItem with- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, write
-
Method Details
-
merge
- Specified by:
mergein interfaceCodeMergeableItem<S extends CodeSimpleMergeableItem<S>>- Parameters:
other- the other item to merge.- Returns:
- the result of the merge. May be this item where the merge was invoked on, or the given
otheritem.
-
merge
- Parameters:
other- the other item to merge.strategy-trueto override,falseotherwise (regular merge, default).- Returns:
- the result of the merge. May be this item where the merge was invoked on, or the given
otheritem.
-