public interface CodeNodeContainer<I>
extends CodeNode, Iterable<I>
CodeItem containing CodeItems of a particular type. It groups these items and all the methods to
operate on them. This makes the API more structured as you do not get too much methods for top-level types such as
CodeType. Further it supports reuse and avoids redundant declaration of methods with
their JavaDoc. So instead of Class.getDeclaredMethods() you will do
CodeType.getMethods().getDeclared().
Since:
1.0.0
Author:
Joerg Hohwiller (hohwille at users.sourceforge.net)