Interface CodeNodeWithFileWriting
- All Superinterfaces:
CodeNode, CodeWithContext
- All Known Subinterfaces:
CodeFile, CodePackage, CodeSource
CodeItem with file writing support.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Method Summary
Modifier and TypeMethodDescriptionvoidRecursively writes thesource codeof this item recursively with all its children to the folder identified by the givenPath.voidRecursively writes thesource codeof this item recursively with all its children to the folder identified by the givenPath.Methods inherited from interface CodeWithContext
getContext, getSource
-
Method Details
-
write
Recursively writes thesource codeof this item recursively with all its children to the folder identified by the givenPath.- Parameters:
targetFolder- thePathpointing to the folder where to write the content of the givenCodePackage.
-
write
Recursively writes thesource codeof this item recursively with all its children to the folder identified by the givenPath.- Parameters:
targetFolder- thePathpointing to the folder where to write the content of the givenCodePackage.encoding- theCharsetused to encode the characters in the file.
-