Interface CodeNAryBooleanOperator
- All Superinterfaces:
CodeItem, CodeNAryOperator, CodeOperator
- All Known Subinterfaces:
CodeNAryHybridOperator
CodeNAryOperator that takes boolean arguments and has a boolean result. Except for instances of
CodeNAryHybridOperator other types of arguments and result are not supported.- Since:
- 1.0.0
- Author:
- Joerg Hohwiller (hohwille at users.sourceforge.net)
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringNameof AND operator.static final StringNameof OR operator.Fields inherited from interface CodeItem
DEFAULT_INDENT, DEFAULT_NEWLINE -
Method Summary
Methods inherited from interface CodeItem
getLanguage, getSourceCode, write, write, write, write, write, writeMethods inherited from interface CodeNAryOperator
isNAry, isNumericMethods inherited from interface CodeOperator
getName, isComparison, isUnary
-
Field Details
-
NAME_OR
-
NAME_AND
-
-
Method Details
-
isBoolean
default boolean isBoolean()- Specified by:
isBooleanin interfaceCodeNAryOperator- Returns:
trueifCodeNAryBooleanOperator,falseotherwise. Iffalsethe result can never be a boolean value.
-